@@ -10,7 +10,7 @@ use IO::Socket;
 use IO::Socket::SSL;
 use Time::Crontab;
 
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 sub new {
     my $class = shift;
@@ -250,13 +250,15 @@ sub load {
                 __PACKAGE__ . "::X::$plugin",
                 __PACKAGE__ . "::$plugin",
             ) {
+                ( my $path = $_ ) =~ s|::|/|g;
+
                 eval "require $_";
                 unless ($@) {
                     $namespace = $_;
                     last;
                 }
                 else {
-                    croak($@) unless ( $@ =~ /^Can't locate/ );
+                    croak($@) unless ( $@ =~ /^Can't locate $path/ );
                 }
             }
             croak("Unable to find or properly load $plugin") unless ($namespace);
@@ -450,7 +452,7 @@ Bot::IRC - Yet Another IRC Bot
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =for markdown [![Build Status](https://travis-ci.org/gryphonshafer/Bot-IRC.svg)](https://travis-ci.org/gryphonshafer/Bot-IRC)
 [![Coverage Status](https://coveralls.io/repos/gryphonshafer/Bot-IRC/badge.png)](https://coveralls.io/r/gryphonshafer/Bot-IRC)
