@@ -6,7 +6,7 @@ use warnings;
 
 use Math::Expression;
 
-our $VERSION = '1.04'; # VERSION
+our $VERSION = '1.05'; # VERSION
 
 sub init {
     my ($bot) = @_;
@@ -19,7 +19,8 @@ sub init {
         sub {
             my ( $bot, $in ) = @_;
             my $value = $expr->EvalToScalar( $expr->Parse( $in->{text} ) );
-            $bot->reply($value) if ($value);
+            ( my $clean_text = $in->{text} ) =~ s/\s+//g;
+            $bot->reply($value) if ( $value and $value ne $clean_text );
         },
     );
 
@@ -40,7 +41,7 @@ Bot::IRC::Math - Bot::IRC evaluate math expressions and return results
 
 =head1 VERSION
 
-version 1.04
+version 1.05
 
 =head1 SYNOPSIS
 
